@@ -4,7 +4,7 @@ from .models import Settings
 
 
 class SettingsAdmin(admin.ModelAdmin):
-    list_display = ['__unicode__', ]
+    list_display = ['key', 'value', 'value_type']
     search_fields = ['key', 'value']
 
-admin.site.register(Settings, SettingsAdmin)
\ No newline at end of file
+admin.site.register(Settings, SettingsAdmin)
